import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { PageTitleCmsRepository } from "./page-title-cms.repository";
import { UpdatePageTitleCmsDto } from "./dto/update-page-title-cms.dto";
import { PageTitleCms } from "./entities/page-title-cms.entity";

@Injectable()
export class PageTitleCmsService {
  constructor(
    @InjectRepository(PageTitleCmsRepository)
    private readonly repository: PageTitleCmsRepository
  ) {
  }

  async updateOrCreateData(
    dto: UpdatePageTitleCmsDto
  ): Promise<PageTitleCms | Error> {
    const isExists = await this.repository.find({ isDeleted: false });
    if (Object.keys(isExists).length === 0) {
      const data = await this.repository.createEntity(dto);
      if (!data) {
        throw new HttpException(
          Constants.NOT_FOUND,
          HttpStatus.NOT_FOUND
        );
      }
      return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
    } else {
      let id = isExists[0].id;
      const data = await this.repository.UpdateEntity(dto, id);
      if (!data) {
        throw new HttpException(
          Constants.UPDATE_FAILED,
          HttpStatus.BAD_REQUEST
        );
      }
      return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
    }
  }

  async findAll(): Promise<PageTitleCms[] | Error> {
    const data = await this.repository.findAll();
    if (!data) {
      throw new HttpException(
        Constants.NOT_FOUND,
        HttpStatus.NOT_FOUND
      );
    }
    return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
  }
}
