import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { CareerRepository } from "./career.repository";
import { CreateCareerDto } from "./dto/create-career.dto";
import { UpdateCareerDto } from "./dto/update-career.dto";
import { Career } from "./entities/career.entity";
import { CareerDepartmentRepository } from "../career-department/career-department.repository";

@Injectable()
export class CareerService {
  constructor(
    @InjectRepository(CareerRepository)
    private readonly repository: CareerRepository,
    @InjectRepository(CareerDepartmentRepository)
    private readonly careerDepartmentRepository: CareerDepartmentRepository
  ) {
  }

  async create(dto: CreateCareerDto): Promise<Career | Error> {
    let departmentData = await this.careerDepartmentRepository.findByName(dto.departmentName);
    if (Object.keys(departmentData).length > 0) {
      dto.departmentNameUrlSlug = departmentData[0].urlSlug;
    }
    const data = await this.repository.createEntity(dto);
    if (!data) {
      throw new HttpException(
        Constants.CREATE_FAILED,
        HttpStatus.BAD_REQUEST
      );
    }
    return ResponseUtils.successResponseHandler(201, "Data created successfully", "data", data);
  }

  async update(id: string, dto: UpdateCareerDto): Promise<Career | Error> {
    const res: any = await this.repository.findOneEntity(id);
    if (!res) {
      throw new HttpException(
        Constants.NOT_FOUND,
        HttpStatus.NOT_FOUND
      );
    }
    let departmentData = await this.careerDepartmentRepository.findByName(dto.departmentName);
    if (Object.keys(departmentData).length > 0) {
      dto.departmentNameUrlSlug = departmentData[0].urlSlug;
    }
    const data = await this.repository.updateEntity(id, dto);
    if (!data) {
      throw new HttpException(
        Constants.UPDATE_FAILED,
        HttpStatus.BAD_REQUEST
      );
    }
    return ResponseUtils.successResponseHandler(200, "Data updated successfully", "data", data);
  }

  async findAll(): Promise<Career[] | Error> {
    const data = await this.repository.findByFilterQuery({});
    if (!data) {
      throw new HttpException(
        Constants.NOT_FOUND,
        HttpStatus.NOT_FOUND
      );
    }
    return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
  }

  async findOne(id: string): Promise<Career[] | Error> {
    const data = await this.repository.findByFilterQuery({ id: id });
    if (!data) {
      throw new HttpException(
        Constants.NOT_FOUND,
        HttpStatus.NOT_FOUND
      );
    }
    return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
  }

  async remove(id: string): Promise<boolean | Error> {
    const data = await this.repository.deleteEntity(id);
    if (!data) {
      throw new HttpException(
        Constants.NOT_FOUND,
        HttpStatus.NOT_FOUND
      );
    }
    return ResponseUtils.buildDeletedData(data, 200, "Data deleted successfully");
  }
}
