import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { BrandPageComponentUiRepository } from "./brand-page-component-ui.repository";
import { UpdateBrandPageComponentUiDto } from "./dto/update-brand-page-component-ui.dto";
import { BrandPageComponentUiEntity } from "./entities/brand-page-component-ui.entity";

@Injectable()
export class BrandPageComponentUiService {
  constructor(
    @InjectRepository(BrandPageComponentUiRepository)
    private readonly repository: BrandPageComponentUiRepository,
    private readonly doSpaceService: DoSpacesService
  ) {
  }

  async updateOrCreateData(
    dto: UpdateBrandPageComponentUiDto
  ): Promise<BrandPageComponentUiEntity | Error> {
    const isExists = await this.repository.find({ isDeleted: false });
    if (Object.keys(isExists).length === 0) {
      const data = await this.repository.createEntity(dto);
      if (!data) {
        throw new HttpException(
          Constants.NOT_FOUND,
          HttpStatus.NOT_FOUND
        );
      }
      return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
    } else {
      let id = isExists[0].id;
      const data = await this.repository.updateEntity(dto, id);
      if (!data) {
        throw new HttpException(
          Constants.UPDATE_FAILED,
          HttpStatus.BAD_REQUEST
        );
      }
      return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
    }
  }

  async findAll(): Promise<BrandPageComponentUiEntity[] | Error> {
    const data = await this.repository.findAll();
    if (!data) {
      throw new HttpException(
        Constants.NOT_FOUND,
        HttpStatus.NOT_FOUND
      );
    }
    return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
  }
}