import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateProductCategoryDto } from "./dto/create-product-category.dto";
import { UpdateProductCategoryDto } from "./dto/update-product-category.dto";
import { ProductCategory } from "./entities/product-category.entity";

@EntityRepository(ProductCategory)
export class ProductCategoryRepository extends Repository<ProductCategory> {

  async createEntity(dto: CreateProductCategoryDto): Promise<any | Error> {
    try {
      const entity = this.create({
        categoryName: dto.categoryName,
        image: dto.image,
        featuredImage: dto.featuredImage
      });
      await this.save(entity);
      return entity;
    } catch (e) {
      return e;
    }
  }

  async findAll(): Promise<any | Error> {
    try {
      return await this.find({
        where: {
          isDeleted: false
        },
        order: {position: 'ASC'}
      });
    } catch (e) {
      return e;
    }
  }

  async findOneEntity(id: string): Promise<ProductCategory[] | Error> {
    try {
      return await this.find({
        where: {
          id: id
        }
      });
    } catch (e) {
      return e;
    }
  }

  async deleteEntity(id: string): Promise<boolean | Error> {
    try {
      const updateResult = await getConnection()
        .createQueryBuilder()
        .update(ProductCategory)
        .set({ isDeleted: true })
        .where("id = :id", { id: id })
        .execute();
      if (updateResult.affected > 0) {
        return true;
      }
      return false;
    } catch (e) {
      return e;
    }
  }

  async updateProductCategory(id: string, dto: UpdateProductCategoryDto): Promise<ProductCategory | Error> {
    try {
      await this.update(id, {
        image: dto.image,
        featuredImage: dto.featuredImage
      });
      return await this.findOne({ where: { id: id } });
    } catch (e) {
      return e;
    }
  }

  async createEntities(dtos: any): Promise<any | Error> {
    await getConnection()
      .createQueryBuilder()
      .insert()
      .into(ProductCategory)
      .values(dtos)
      .execute();
  }

  async findOneCategory(category: any): Promise<any | Error> {
    try {
      return await this.findOne({
        where: {
          categoryName: category,
          isDeleted: false
        }
      });
    } catch (e) {
      return e;
    }
  }
}