import { Body, Controller, Delete, Get, Param, Patch, Post, UseGuards } from "@nestjs/common";
import { Constants } from "src/utils/constants";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { UploadedFiles, UseInterceptors } from "@nestjs/common/decorators";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { UploadedMulterFileI } from "../SpacesModule/SpacesService";
import { FooterImageService } from "./footer-image.service";
import { CreateFooterImageDto } from "./dto/create-footer-image.dto";
import { UpdateFooterImageDto } from "./dto/update-footer-image.dto";

@Controller({ path: "footer-image", version: Constants.API_VERSION_1 })

export class FooterImageController {
  constructor(private readonly service: FooterImageService) {
  }

  @Post()
  // @UseGuards(AdminAuthGuard)
  @UseInterceptors(FileFieldsInterceptor(
    [
      { name: "image", maxCount: 1 }
    ]
  ))
  create(
    @Body() dto: CreateFooterImageDto,
    @UploadedFiles() files: {
      image: UploadedMulterFileI
    }
  ) {
    return this.service.create(dto, files);
  }

  @Get()
  // @UseGuards(AdminAuthGuard)
  findAll() {
    return this.service.findAll();
  }

  @Get(":id")
  @UseGuards(AdminAuthGuard)
  findOne(@Param("id") id: string) {
    return this.service.findOne(id);
  }

  @Patch("/:id")
  @UseGuards(AdminAuthGuard)
  @UseInterceptors(FileFieldsInterceptor(
    [
      { name: "image", maxCount: 1 }
    ]
  ))
  update(
    @Param("id") id: string,
    @Body() dto: UpdateFooterImageDto,
    @UploadedFiles() files: {
      image: UploadedMulterFileI
    }
  ) {
    return this.service.update(id, dto, files);
  }

  @Delete(":id")
  @UseGuards(AdminAuthGuard)
  async remove(@Param("id") id: string) {
    return await this.service.remove(id);
  }
}
